@@ -4,11 +4,10 @@ from .web_scraper.tool import WebScraper
 from .sql_client.tool import SqlClient
 from .email_client.tool import EmailClient
 from .aws_cli.tool import AwsCli
-from .rest_api.tool import RestApi
-from .pdf_reader.tool import PdfReader
+from .rest_api_client.tool import RestApiClient
 from .file_manager.tool import FileManager
-from .text_processor.tool import TextProcessor
-from .vector_storage_client.tool import VectorStorageClient
+from .knowledge_base_client.tool import KnowledgeBaseClient
+from .date_time.tool import DateTime
 
 __all__ = [
     "Calculator",
@@ -17,9 +16,8 @@ __all__ = [
     "SqlClient",
     "EmailClient",
     "AwsCli",
-    "RestApi",
-    "PdfReader",
+    "RestApiClient",
     "FileManager",
-    "TextProcessor",
-    "VectorStorageClient"
+    "KnowledgeBaseClient",
+    "DateTime"
 ]
